@@ -12,6 +12,9 @@ def main():
     do_parser.add_argument('task', metavar='task', type=str, nargs='?', default='', help='a task to exec')
     do_parser.set_defaults(func=do)
 
+    do_parser = sub_parsers.add_parser('rm', help='remove stopped containers')
+    do_parser.set_defaults(func=rm)
+
     tasks_parser = sub_parsers.add_parser('tasks', help='show tasks')
     tasks_parser.set_defaults(func=tasks)
 
@@ -22,6 +25,9 @@ def do(args):
     code = Project(args.image_name).do(args.task)
     sys.exit(code)
 
+def rm(args):
+    Project(args.image_name).rm()
+
 def tasks(args):
     tasks = Project(args.image_name).tasks()
     print('[task]'.ljust(32), '[command]')
